@@ -43,7 +43,6 @@ OC.L10N.register(
     "Wrong image" : "Verkeerde afbeelding",
     "The file was not uploaded. Check your server logs." : "Het bestand is niet geupload. Bekijk uw Server-logboeken",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Installeer de app op je mobiel om overal toegang tot je notities te krijgen.",
-    "Details" : "Details",
     "Delete note" : "Verwijder notitie",
     "Remove from favorites" : "Verwijderen uit favorieten",
     "Add to favorites" : "Toevoegen aan favorieten",
@@ -69,19 +68,8 @@ OC.L10N.register(
     "Last week" : "Vorige week",
     "This month" : "Deze maand",
     "Last month" : "Vorige maand",
-    "Category" : "Categorie",
-    "Uncategorized" : "Niet gecategoriseerd ",
-    "Set category" : "Bepaal categorie",
-    "Click here to save manually" : "Klik hier om handmatig op te slaan",
-    "Saving failed!" : "Opslaan mislukt!",
-    "Last modified: {date}" : "Laatst gewijzigd: {date}",
-    "Note has unsaved changes" : "De notitie heeft niet-opgeslagen wijzigingen.",
-    "Subcategory" : "Subcategorie",
-    "_%n word_::_%n words_" : ["%n woord","%n woorden"],
-    "_%n character_::_%n characters_" : ["%n teken","%n tekens"],
     "Use Markdown markups to style your text." : "Gebruik Markdown markeringen om je tekst op te maken.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Start een nieuwe notitie door op \"{newnote}\" te klikken in de app navigatie.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Je kunt sub-categorieën maken door “/” te gebruiken als scheidingsteken tussen hoofdcategorie en sub-categorie, bijv. “{parent}/{sub}”.",
     "Note not found." : "Notitie niet gevonden.",
     "Note is locked." : "Notitie is geblokkeerd.",
     "Insufficient storage." : "Onvoldoende opslagruimte",
@@ -100,6 +88,7 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "Favoriet bijwerken voor notitie {id} mislukt.",
     "Updating the note's category has failed. Is the target directory writable?" : "Bijwerken van de notitiecategorie mislukt. Is de doelmap beschrijfbaar?",
     "Updating the category for note {id} has failed." : "Categorie bijwerken voor notitie {id} mislukt.",
+    "Uncategorized" : "Niet gecategoriseerd ",
     "Tasks" : "Taken",
     "Buy Fries" : "Koop frietjes",
     "Birthdays" : "Verjaardagen",
