@@ -4,10 +4,14 @@ declare(strict_types=1);
 
 namespace OCA\Notes\Service;
 
+use OCP\Files\File;
 use OCP\Files\Folder;
 use OCP\Files\IRootFolder;
 use OCP\Files\Node;
 use OCP\IDBConnection;
+use OCP\IUserSession;
+use OCP\Share\IManager;
+use OCP\Share\IShare;
 
 class NoteUtil {
 	private const MAX_TITLE_LENGTH = 100;
@@ -15,23 +19,34 @@ class NoteUtil {
 	private IDBConnection $db;
 	private IRootFolder $root;
 	private TagService $tagService;
+	private IManager $shareManager;
+	private IUserSession $userSession;
 
 	public function __construct(
 		Util $util,
 		IRootFolder $root,
 		IDBConnection $db,
-		TagService $tagService
+		TagService $tagService,
+		IManager $shareManager,
+		IUserSession $userSession
 	) {
 		$this->util = $util;
 		$this->root = $root;
 		$this->db = $db;
 		$this->tagService = $tagService;
+		$this->shareManager = $shareManager;
+		$this->userSession = $userSession;
 	}
 
 	public function getRoot() : IRootFolder {
 		return $this->root;
 	}
 
+	public function getPathForUser(File $file) {
+		$userFolder = $this->root->getUserFolder($this->userSession->getUser()->getUID());
+		return $userFolder->getRelativePath($file->getPath());
+	}
+
 	public function getTagService() : TagService {
 		return $this->tagService;
 	}
@@ -146,6 +161,7 @@ class NoteUtil {
 	 * @return Folder
 	 */
 	public function getOrCreateFolder(string $path, bool $create = true) : Folder {
+		$folder = null;
 		if ($this->root->nodeExists($path)) {
 			$folder = $this->root->get($path);
 		} elseif ($create) {
@@ -202,4 +218,29 @@ class NoteUtil {
 			throw new NoteNotWritableException();
 		}
 	}
+
+	public function getShareTypes(File $file): array {
+		$userId = $file->getOwner()->getUID();
+		$requestedShareTypes = [
+			IShare::TYPE_USER,
+			IShare::TYPE_GROUP,
+			IShare::TYPE_LINK,
+			IShare::TYPE_REMOTE,
+			IShare::TYPE_EMAIL,
+			IShare::TYPE_ROOM,
+			IShare::TYPE_DECK,
+			IShare::TYPE_SCIENCEMESH,
+		];
+		$shareTypes = [];
+
+		foreach ($requestedShareTypes as $shareType) {
+			$shares = $this->shareManager->getSharesBy($userId, $shareType, $file, false, 1, 0);
+
+			if (count($shares)) {
+				$shareTypes[] = $shareType;
+			}
+		}
+
+		return $shareTypes;
+	}
 }
